@@ -62,6 +62,9 @@ pref("browser.cache.memory.enable",         true);
 pref("browser.cache.disk_cache_ssl",        false);
 // 0 = once-per-session, 1 = each-time, 2 = never, 3 = when-appropriate/automatically
 pref("browser.cache.check_doc_frequency",   3);
+// Fastback caching - if this pref is negative, then we calculate the number
+// of content viewers to cache based on the amount of available memory.
+pref("browser.sessionhistory.max_total_viewers", -1);
 
 pref("browser.display.use_document_fonts",  1);  // 0 = never, 1 = quick, 2 = always
 pref("browser.display.use_document_colors", true);
@@ -103,7 +106,7 @@ pref("browser.chrome.image_icons.max_size", 1024);
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 107 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 110 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -111,7 +114,7 @@ pref("accessibility.warn_on_browsewithcaret", true);
 // unless accessibility.tabfocus is set by the user.
 pref("accessibility.tabfocus", 7);
 pref("accessibility.tabfocus_applies_to_xul", false);
-//@line 118 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 121 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -264,19 +267,32 @@ pref("capability.policy.default.Navigator.preferenceinternal.set", "UniversalPre
 
 pref("capability.policy.default.Window.blur.get", "allAccess");
 pref("capability.policy.default.Window.close.get", "allAccess");
-pref("capability.policy.default.Window.closed", "allAccess");
+pref("capability.policy.default.Window.closed.get", "allAccess");
 pref("capability.policy.default.Window.Components", "allAccess");
-pref("capability.policy.default.Window.document", "allAccess");
+pref("capability.policy.default.Window.document.get", "allAccess");
 pref("capability.policy.default.Window.focus.get", "allAccess");
-pref("capability.policy.default.Window.frames", "allAccess");
-pref("capability.policy.default.Window.history", "allAccess");
-pref("capability.policy.default.Window.length", "allAccess");
+pref("capability.policy.default.Window.frames.get", "allAccess");
+pref("capability.policy.default.Window.history.get", "allAccess");
+pref("capability.policy.default.Window.length.get", "allAccess");
 pref("capability.policy.default.Window.location", "allAccess");
-pref("capability.policy.default.Window.opener", "allAccess");
-pref("capability.policy.default.Window.parent", "allAccess");
-pref("capability.policy.default.Window.self", "allAccess");
-pref("capability.policy.default.Window.top", "allAccess");
-pref("capability.policy.default.Window.window", "allAccess");
+pref("capability.policy.default.Window.opener.get", "allAccess");
+pref("capability.policy.default.Window.parent.get", "allAccess");
+pref("capability.policy.default.Window.self.get", "allAccess");
+pref("capability.policy.default.Window.top.get", "allAccess");
+pref("capability.policy.default.Window.window.get", "allAccess");
+
+pref("capability.policy.default.XULControllers.commandDispatcher", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerForCommand", "noAccess");
+pref("capability.policy.default.XULControllers.insertControllerAt", "noAccess");
+pref("capability.policy.default.XULControllers.removeControllerAt", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerAt", "noAccess");
+pref("capability.policy.default.XULControllers.appendController", "noAccess");
+pref("capability.policy.default.XULControllers.removeController", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerId", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerById", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerCount", "noAccess");
+pref("capability.policy.default.Selection.addSelectionListener", "UniversalXPConnect");
+pref("capability.policy.default.Selection.removeSelectionListener", "UniversalXPConnect");
 
 // Restrictions on the DOM for mail/news - see bugs 66938 and 84545
 pref("capability.policy.mailnews.sites", "mailbox: imap: news:");
@@ -322,6 +338,7 @@ pref("capability.policy.mailnews.Window.screenY.set", "noAccess");
 pref("capability.policy.mailnews.Window.sizeToContent", "noAccess");
 pref("capability.policy.mailnews.document.load", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.channel", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.getInterface", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.responseXML", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.responseText", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.status", "noAccess");
@@ -339,8 +356,8 @@ pref("capability.policy.mailnews.XMLHttpRequest.onerror", "noAccess");
 pref("capability.policy.mailnews.XMLHttpRequest.onreadystatechange", "noAccess");
 pref("capability.policy.mailnews.XMLSerializer.serializeToString", "noAccess");
 pref("capability.policy.mailnews.XMLSerializer.serializeToStream", "noAccess");
-pref("capability.policy.mailnews.DOMParser,parseFromString", "noAccess");
-pref("capability.policy.mailnews.DOMParser,parseFromStream", "noAccess");
+pref("capability.policy.mailnews.DOMParser.parseFromString", "noAccess");
+pref("capability.policy.mailnews.DOMParser.parseFromStream", "noAccess");
 pref("capability.policy.mailnews.SOAPCall.transportURI", "noAccess");
 pref("capability.policy.mailnews.SOAPCall.verifySourceHeader", "noAccess");
 pref("capability.policy.mailnews.SOAPCall.invoke", "noAccess");
@@ -389,6 +406,7 @@ pref("capability.policy.mailnews.WebServiceProxyFactory.onError", "noAccess");
 
 // XMLExtras
 pref("capability.policy.default.XMLHttpRequest.channel", "noAccess");
+pref("capability.policy.default.XMLHttpRequest.getInterface", "noAccess");
 pref("capability.policy.default.DOMParser.parseFromStream", "noAccess");
 
 // Clipboard
@@ -457,7 +475,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 466 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 484 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -577,6 +595,7 @@ pref("network.IDN.whitelist.fi", true);
 pref("network.IDN.whitelist.gr", true);
 pref("network.IDN.whitelist.hu", true);
 pref("network.IDN.whitelist.io", true);
+pref("network.IDN.whitelist.is", true);
 pref("network.IDN.whitelist.jp", true);
 pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
@@ -587,19 +606,19 @@ pref("network.IDN.whitelist.sh", true);
 pref("network.IDN.whitelist.th", true);
 pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
+pref("network.IDN.whitelist.vn", true);
 
 // non-ccTLDs
+pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
 pref("network.IDN.whitelist.museum", true);
+pref("network.IDN.whitelist.org", true);
 
 // If a domain includes any of the following characters, it may be a spoof 
 // attempt and so we always display the domain name as punycode. This would 
 // override the settings "network.IDN_show_punycode" and 
-// "netword.IDN.whitelist.*".
-// The list currently contains the characters:
-// U+2044 FRACTION SLASH
-// U+2215 DIVISION SLASH
-pref("network.IDN.blacklist_chars", "⁄∕");
+// "network.IDN.whitelist.*".
+pref("network.IDN.blacklist_chars", "\u0020\u00A0\u00BC\u00BD\u01C3\u0337\u0338\u05C3\u05F4\u06D4\u0702\u115F\u1160\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u200B\u2024\u2027\u2028\u2029\u202F\u2039\u203A\u2044\u205F\u2154\u2155\u2156\u2159\u215A\u215B\u215F\u2215\u23AE\u29F6\u29F8\u2AFB\u2AFD\u2FF0\u2FF1\u2FF2\u2FF3\u2FF4\u2FF5\u2FF6\u2FF7\u2FF8\u2FF9\u2FFA\u2FFB\u3000\u3002\u3014\u3015\u3033\u3164\u321D\u321E\u33AE\u33AF\u33C6\u33DF\uFE14\uFE15\uFE3F\uFE5D\uFE5E\uFEFF\uFF0E\uFF0F\uFF61\uFFA0\uFFF9\uFFFA\uFFFB\uFFFC\uFFFD");
 
 // This preference specifies a list of domains for which DNS lookups will be
 // IPv4 only. Works around broken DNS servers which can't handle IPv6 lookups
@@ -615,7 +634,7 @@ pref("network.standard-url.escape-utf8", true);
 
 // This preference controls whether or not URLs are always encoded and sent as
 // UTF-8.
-pref("network.standard-url.encode-utf8", true);
+pref("network.standard-url.encode-utf8", false);
 
 // Idle timeout for ftp control connections - 5 minute default
 pref("network.ftp.idleConnectionTimeout", 300);
@@ -652,7 +671,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 666 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 685 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -774,16 +793,20 @@ pref("mousewheel.withnokey.sysnumlines",true);
 pref("mousewheel.withcontrolkey.action",0);
 pref("mousewheel.withcontrolkey.numlines",1);
 pref("mousewheel.withcontrolkey.sysnumlines",true);
+// mousewheel.withshiftkey, see the Mac note below.
 pref("mousewheel.withshiftkey.action",0);
 pref("mousewheel.withshiftkey.numlines",1);
 pref("mousewheel.withshiftkey.sysnumlines",true);
 pref("mousewheel.withaltkey.action",2);
 pref("mousewheel.withaltkey.numlines",1);
 pref("mousewheel.withaltkey.sysnumlines",false);
+pref("mousewheel.withmetakey.action",0);
+pref("mousewheel.withmetakey.numlines",1);
+pref("mousewheel.withmetakey.sysnumlines",true);
 
 // on platforms where scroll messages differ between horizontal scroll
 // and back/forward button events we can activate them by default
-//@line 821 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 854 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 // disable horizontal scrolling to be able to use back/forward buttons
 pref("mousewheel.horizscroll.withnokey.action",2);
 pref("mousewheel.horizscroll.withnokey.numlines",-1);
@@ -797,7 +820,10 @@ pref("mousewheel.horizscroll.withshiftkey.sysnumlines",false);
 pref("mousewheel.horizscroll.withaltkey.action",2);
 pref("mousewheel.horizscroll.withaltkey.numlines",-1);
 pref("mousewheel.horizscroll.withaltkey.sysnumlines",false);
-//@line 835 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+pref("mousewheel.horizscroll.withmetakey.action",2);
+pref("mousewheel.horizscroll.withmetakey.numlines",-1);
+pref("mousewheel.horizscroll.withmetakey.sysnumlines",false);
+//@line 871 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
 pref("profile.confirm_automigration",true);
 // profile.migration_behavior determines how the profiles root is set
@@ -930,15 +956,15 @@ pref("dom.max_script_run_time", 5);
 
 pref("svg.enabled", true);
 
-//@line 1298 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 1334 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1488 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 1521 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1673 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 1710 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1754 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 1791 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1757 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 1794 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1014,7 +1040,7 @@ pref("font.allow_double_byte_special_chars", true);
 
 // ar
 
-//@line 1833 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 1870 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.name.serif.el", "serif");
 pref("font.name.sans-serif.el", "sans-serif");
@@ -1073,7 +1099,7 @@ pref("font.name.sans-serif.zh-HK", "sans-serif");
 pref("font.name.monospace.zh-HK", "monospace");
 
 // zh-TW
-//@line 1952 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 1989 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.default.ar", "sans-serif");
 pref("font.size.variable.ar", 16);
@@ -1291,11 +1317,11 @@ pref("print.postscript.nativefont.zh-CN",          "");
 pref("print.postscript.nativefont.zh-TW",          "");
 pref("print.postscript.nativefont.zh-HK",          "");
 
-//@line 2172 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 2209 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2240 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 2277 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2266 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 2303 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2286 "/build/andrew/sm1/mozilla/modules/libpref/src/init/all.js"
+//@line 2323 "/home/robert/tinderbox/release-SeaMonkey-1.0/Linux_2.4.21-303-default_Clobber/mozilla/modules/libpref/src/init/all.js"
 
